==> release.12.0.73.1.tgz: prontus/cpan/js-local/EventosRedes.class.js <==
var EventosRedes = {
    init: function() {
        $('.mostrar_secret').click(function () {
            var span = $(this).children('span');
            var input = $(this).siblings('input');

            if ($(span).hasClass('glyphicon-eye-open')) {
                $(span).removeClass('glyphicon-eye-open').addClass('glyphicon-eye-close');
                $(input).prop('type', 'text');
            } else {
                $(span).removeClass('glyphicon-eye-close').addClass('glyphicon-eye-open');
                $(input).prop('type', 'password');
            }

            return false;
        });

        $('#obtener_youtube_authorization_code').click(function(e) {
            EventosRedes.obtener_authorization_code(this);
            return false;
        });

        $('#obtener_youtube_refresh_token').click(function(e) {
            EventosRedes.obtener_refresh_token(this);
            return false;
        });

        $('#obtener_youtube_oauth_token').click(function(e) {
            EventosRedes.obtener_oauth_token(this);
            return false;
        });

        $('#mostrar_ayuda_fb_app').click(function(e) {
            showModalAlert({
                title: 'Cómo obtener las credenciales para posting en Facebook',
                type: 'blue',
                msg: $('#texto_ayuda_fb').html()
            });
        });
    },

    obtener_authorization_code: function(element) {
        $.get($(element).data('url'), function(data) {
            showModalAlert({
                title: 'Autorizar la aplicación YouTube',
                type: 'blue',
                msg: data
            });
        });
    },

    // intenta obtener el refresh_token para la app youtube
    obtener_refresh_token: function(element) {
        var url = $(element).data('url');
        var auth_code = $('#YOUTUBE_AUTHORIZATION_CODE').val();
        $.getJSON(url, {auth_code: auth_code}, function(data) {
            if (data.status == 0) {
                showModalAlert({
                    title: 'Error',
                    type: 'red',
                    msg: data.msg || "No fue posible obtener el token solicitado."
                });
            } else {
                var results = data.msg.match(/refresh_token:(.+)$/);
                var refresh_token = '';
                if (results) {
                    refresh_token = results[1];
                } else {
                    showModalAlert({
                        title: 'Error',
                        type: 'red',
                        msg: "No fue posible obtener el token solicitado."
                    });
                }
                showModalAlert({
                    title: 'Éxito',
                    type: 'green',
                    msg: "Refresh Token obtenido correctamente."
                });
                $('#YOUTUBE_REFRESH_TOKEN').val(refresh_token);
            }
        });
        return false;
    },

    // intenta obtener el oauth_token para la app youtube
    obtener_oauth_token: function(element) {
        var url = $(element).data('url');
        var auth_code = $('#YOUTUBE_AUTHORIZATION_CODE').val();
        var refresh_token = $('#YOUTUBE_REFRESH_TOKEN').val();
        $.getJSON(url, {auth_code: auth_code, refresh_token: refresh_token}, function(data) {
            if (data.status == 0) {
                showModalAlert({
                    title: 'Error',
                    type: 'red',
                    msg: data.msg || "No fue posible obtener el token solicitado."
                });
            } else {
                var results = data.msg.match(/oauth_token:(.+)$/);
                var oauth_token = '';
                if (results) {
                    oauth_token = results[1];
                } else {
                    showModalAlert({
                        title: 'Error',
                        type: 'red',
                        msg: "No fue posible obtener el token solicitado."
                    });
                }
                showModalAlert({
                    title: 'Éxito',
                    type: 'green',
                    msg: "OAuth Token obtenido correctamente."
                });
                $('#YOUTUBE_OAUTH_TOKEN').val(oauth_token);
            }
        });
        return false;
    }
};

$(document).ready(function () {
    EventosRedes.init();
});

==> release.12.3.1.2.tgz: prontus/cpan/js-local/EventosRedes.class.js <==
var EventosRedes = {
    init: function() {
        $('.mostrar_secret').click(function () {
            var span = $(this).children('span');
            var input = $(this).siblings('input');

            if ($(span).hasClass('glyphicon-eye-open')) {
                $(span).removeClass('glyphicon-eye-open').addClass('glyphicon-eye-close');
                $(input).prop('type', 'text');
            } else {
                $(span).removeClass('glyphicon-eye-close').addClass('glyphicon-eye-open');
                $(input).prop('type', 'password');
            }

            return false;
        });

        $('#obtener_youtube_authorization_code').click(function(e) {
            EventosRedes.obtener_authorization_code(this);
            return false;
        });

        $('#obtener_youtube_refresh_token').click(function(e) {
            EventosRedes.obtener_refresh_token(this);
            return false;
        });

        $('#obtener_youtube_oauth_token').click(function(e) {
            EventosRedes.obtener_oauth_token(this);
            return false;
        });

        $('#mostrar_ayuda_fb_app').click(function(e) {
            showModalAlert({
                title: ProntusL10n.get('eventosredes_posting_fb'),
                type: 'blue',
                msg: $('#texto_ayuda_fb').html()
            });
        });
    },

    obtener_authorization_code: function(element) {
        $.get($(element).data('url'), function(data) {
            showModalAlert({
                title: ProntusL10n.get('eventosredes_app_yt'),
                type: 'blue',
                msg: data
            });
        });
    },

    // intenta obtener el refresh_token para la app youtube
    obtener_refresh_token: function(element) {
        var url = $(element).data('url');
        var auth_code = $('#YOUTUBE_AUTHORIZATION_CODE').val();
        $.getJSON(url, {auth_code: auth_code}, function(data) {
            if (data.status == 0) {
                showModalAlert({
                    title: ProntusL10n.get('global_error_title'),
                    type: 'red',
                    msg: data.msg || ProntusL10n.get('eventosredes_not_token')
                });
            } else {
                var results = data.msg.match(/refresh_token:(.+)$/);
                var refresh_token = '';
                if (results) {
                    refresh_token = results[1];
                } else {
                    showModalAlert({
                        title: ProntusL10n.get('global_error_title'),
                        type: 'red',
                        msg: ProntusL10n.get('eventosredes_not_token')
                    });
                }
                showModalAlert({
                    title: ProntusL10n.get('global_success'),
                    type: 'green',
                    msg: ProntusL10n.get('eventosredes_refresh_token')
                });
                $('#YOUTUBE_REFRESH_TOKEN').val(refresh_token);
            }
        });
        return false;
    },

    // intenta obtener el oauth_token para la app youtube
    obtener_oauth_token: function(element) {
        var url = $(element).data('url');
        var auth_code = $('#YOUTUBE_AUTHORIZATION_CODE').val();
        var refresh_token = $('#YOUTUBE_REFRESH_TOKEN').val();
        $.getJSON(url, {auth_code: auth_code, refresh_token: refresh_token}, function(data) {
            if (data.status == 0) {
                showModalAlert({
                    title: ProntusL10n.get('global_error_title'),
                    type: 'red',
                    msg: data.msg || ProntusL10n.get('eventosredes_not_token')
                });
            } else {
                var results = data.msg.match(/oauth_token:(.+)$/);
                var oauth_token = '';
                if (results) {
                    oauth_token = results[1];
                } else {
                    showModalAlert({
                        title: ProntusL10n.get('global_error_title'),
                        type: 'red',
                        msg: ProntusL10n.get('eventosredes_not_token')
                    });
                }
                showModalAlert({
                    title: 'Éxito',
                    type: 'green',
                    msg: ProntusL10n.get('eventosredes_oauth_token')
                });
                $('#YOUTUBE_OAUTH_TOKEN').val(oauth_token);
            }
        });
        return false;
    }
};

$(document).ready(function () {
    EventosRedes.init();
});
